==> 1.2.0-alpha.2.tar.gz: lib/src/api_paths.dart <==
import 'package:rec_api_dart/src/api_path.dart';

/// [API Documentation](https://github.com/QbitArtifacts/rec_app_v2/wiki/Api-Documentation) available.
class ApiPaths {
  // Transactions
  static ApiPath token = ApiPath('/oauth/v3/token');
  static ApiPath refreshToken = ApiPath('/oauth/v2/token');
  static ApiPath transactions = ApiPath('/user/v2/wallet/transactions');
  static ApiPath transactionsPerDay =
      ApiPath('/user/v1/wallet/day/transactions');
  static ApiPath vendorData = ApiPath('/transaction/v1/vendor');
  static ApiPath payment = ApiPath('/methods/v3/out/rec');

  // Public
  static ApiPath sendPublicSmsCode = ApiPath('/app/v4/sms-code');
  static ApiPath recoverPassword = ApiPath('/app/v4/recover-password');
  static ApiPath verifyPhone = ApiPath('/app/v4/validate-phone');
  static ApiPath register = ApiPath('/app/v4/register');
  static ApiPath registerRezeroB2B = ApiPath('/rezero_b2b/v4/register');

  // Security
  static ApiPath changePassword = ApiPath(
    '/user/v4/users/security/change-password',
  );
  static ApiPath changePin = ApiPath(
    '/user/v4/users/security/change-pin',
  );
  static ApiPath sendUserSmsCode = ApiPath('/user/v4/users/security/sms-code');

  // User
  static ApiPath currentUserAccount = ApiPath('/user/v1/account');
  static ApiPath currentUserKyc = ApiPath('/user/v3/kycs');
  static ApiPath userAccounts = ApiPath('/user/v1/companies');
  static ApiPath changeAccount = ApiPath('/user/v1/activegroup');
  static ApiPath getContacts = ApiPath('/user/v1/public_phone_list');
  static ApiPath uploadFile = ApiPath('/user/v1/upload_file');
  static ApiPath listCards = ApiPath('/company/v1/credit_card');
  static ApiPath unlockUser = ApiPath('app/v4/unlock-user');

  static ApiPath campaigns = ApiPath('/user/v3/campaigns');
  static ApiPath acceptTos = ApiPath('/user/v4/campaign/accept_tos');

  // Accounts
  static ApiPath accounts = ApiPath('/user/v3/accounts');
  static ApiPath accountsSearch = ApiPath('/user/v4/accounts/search');
  static ApiPath accountsAddUser = ApiPath('/manager/v1/groups');
  static ApiPath accountsPermissions = ApiPath('/users/v1/usersbygroup');
  static ApiPath accountsEditRole = ApiPath('/manager/v1/groupsrole');
  static ApiPath accountsAddNew = ApiPath('/user/v1/new/account');

  // Recharge
  static ApiPath rechargeRecs = ApiPath('/methods/v3/in/lemonway');
  static ApiPath getExchangers = ApiPath('/user/v1/wallet/exchangers');

  // Offers
  static ApiPath offers = ApiPath('/company/v4/offers');

  // Documents
  static ApiPath documentKinds = ApiPath('/user/v3/document_kinds');
  static ApiPath documents = ApiPath('/user/v4/documents');

  // Activities
  static ApiPath activities = ApiPath('/public/v4/activities');

  // Qualifications
  static ApiPath qualifications = ApiPath('/user/v3/qualifications');
}

==> 1.4.0-alpha.2.tar.gz: lib/src/api_paths.dart <==
import 'package:rec_api_dart/src/api_path.dart';

/// [API Documentation](https://github.com/QbitArtifacts/rec_app_v2/wiki/Api-Documentation) available.
class ApiPaths {
  // Transactions
  static ApiPath token = ApiPath('/oauth/v3/token');
  static ApiPath refreshToken = ApiPath('/oauth/v2/token');
  static ApiPath transactions = ApiPath('/user/v2/wallet/transactions');
  static ApiPath recOutTx = ApiPath('/methods/v3/out/rec');
  static ApiPath recInTx = ApiPath('/methods/v3/in/rec');

  static ApiPath transactionsPerDay = ApiPath('/user/v1/wallet/day/transactions');
  static ApiPath vendorData = ApiPath('/transaction/v1/vendor');
  static ApiPath payment = ApiPath('/methods/v3/out/rec');
  static ApiPath refund = ApiPath('/methods/v3/refund/rec');

  // Public
  static ApiPath sendPublicSmsCode = ApiPath('/app/v4/sms-code');
  static ApiPath recoverPassword = ApiPath('/app/v4/recover-password');
  static ApiPath verifyPhone = ApiPath('/app/v4/validate-phone');
  static ApiPath register = ApiPath('/app/v4/register');
  static ApiPath registerRezeroB2B = ApiPath('/rezero_b2b/v4/register');
  static ApiPath configurationSettings = ApiPath('/public/v3/configuration_settings');

  // Security
  static ApiPath changePassword = ApiPath(
    '/user/v4/users/security/change-password',
  );
  static ApiPath changePin = ApiPath(
    '/user/v4/users/security/change-pin',
  );
  static ApiPath sendUserSmsCode = ApiPath('/user/v4/users/security/sms-code');

  // User
  static ApiPath currentUserAccount = ApiPath('/user/v1/account');
  static ApiPath currentUserKyc = ApiPath('/user/v3/kycs');
  static ApiPath userAccounts = ApiPath('/user/v1/companies');
  static ApiPath changeAccount = ApiPath('/user/v1/activegroup');
  static ApiPath getContacts = ApiPath('/user/v1/public_phone_list');
  static ApiPath uploadFile = ApiPath('/user/v1/upload_file');
  static ApiPath listCards = ApiPath('/company/v1/credit_card');
  static ApiPath unlockUser = ApiPath('app/v4/unlock-user');

  static ApiPath campaigns = ApiPath('/user/v3/campaigns');
  static ApiPath acceptTos = ApiPath('/user/v4/campaign/accept_tos');

  // Accounts
  static ApiPath accounts = ApiPath('/user/v3/accounts');

  /// Used as a base to build more complex urls
  static ApiPath account = ApiPath('/user/v3/account');

  static ApiPath accountsSearch = ApiPath('/user/v4/accounts/search');
  static ApiPath accountsAddUser = ApiPath('/manager/v1/groups');
  static ApiPath accountsPermissions = ApiPath('/users/v1/usersbygroup');
  static ApiPath accountsEditRole = ApiPath('/manager/v1/groupsrole');
  static ApiPath accountsAddNew = ApiPath('/user/v1/new/account');
  static ApiPath removeCreditCard = ApiPath('/company/v1/credit_card');

  // Recharge
  static ApiPath rechargeRecs = ApiPath('/methods/v3/in/lemonway');
  static ApiPath getExchangers = ApiPath('/user/v1/wallet/exchangers');

  // Offers
  static ApiPath offers = ApiPath('/company/v4/offers');

  // Documents
  static ApiPath documentKinds = ApiPath('/user/v3/document_kinds');
  static ApiPath documents = ApiPath('/user/v4/documents');

  // Activities
  static ApiPath activities = ApiPath('/public/v4/activities');

  // Qualifications
  static ApiPath qualifications = ApiPath('/user/v3/qualifications');
  static ApiPath badges = ApiPath('/public/v3/badges');

  // Awards
  static ApiPath allAwards = ApiPath('/user/v3/awards');
  static ApiPath awards = ApiPath('awards');
  static ApiPath awardItems = ApiPath('award_items');
}
